==> smartgwt-4.1p.zip: com/smartgwt/client/types/ArrowStyle.java <==
package com.smartgwt.client.types;


/*
 * Smart GWT (GWT for SmartClient)
 * Copyright 2008 and beyond, Isomorphic Software, Inc.
 *
 * Smart GWT is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License version 3
 * as published by the Free Software Foundation.  Smart GWT is also
 * available under typical commercial license terms - see
 * http://smartclient.com/license
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 */
/* sgwtgen */
 
/**
 * Supported styles for arrowheads
 */
public enum ArrowStyle implements ValueEnum {
    /**
     * Solid triangle
     * <P>
     * If this enumerated value is used in a {@link com.smartgwt.client.docs.ComponentXML Component XML}
     * file or server-side DataSource descriptor (.ds.xml file), use the value "block".
     */
    BLOCK("block"),
    /**
     * arrow rendered as an open triangle. Only applies to {@link com.smartgwt.client.widgets.drawing.DrawLinePath
     * DrawLinePaths} - for other items this will be treated as <code>"block"</code>
     * <P>
     * If this enumerated value is used in a {@link com.smartgwt.client.docs.ComponentXML Component XML}
     * file or server-side DataSource descriptor (.ds.xml file), use the value "open".
     */
    OPEN("open"),
    /**
     * Don't render an arrowhead at all
     */
    NULL(null);
    private String value;

    ArrowStyle(String value) {
        this.value = value;
    }

    public String getValue() {
        return this.value;
    }
}

==> smartgwt-14.1p.zip: com/smartgwt/client/types/ArrowStyle.java <==
package com.smartgwt.client.types;


/*
 * Smart GWT (GWT for SmartClient)
 * Copyright 2008 and beyond, Isomorphic Software, Inc.
 *
 * Smart GWT is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License version 3
 * as published by the Free Software Foundation.  Smart GWT is also
 * available under typical commercial license terms - see
 * http://smartclient.com/license
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 */
/* sgwtgen */
 
/**
 * Supported styles for arrowheads.
 */
public enum ArrowStyle implements ValueEnum {
    /**
     * Filled triangle.
     * <P>
     * If this enumerated value is used in a {@link com.smartgwt.client.docs.ComponentXML Component XML}
     * file or server-side DataSource descriptor (.ds.xml file), use the value "block".
     */
    BLOCK("block"),
    /**
     * Two lines are drawn on each side of the path.
     * <P>
     * If this enumerated value is used in a {@link com.smartgwt.client.docs.ComponentXML Component XML}
     * file or server-side DataSource descriptor (.ds.xml file), use the value "open".
     */
    OPEN("open");
    private String value;

    ArrowStyle(String value) {
        this.value = value;
    }

    public String getValue() {
        return this.value;
    }
}
